Test Confirmation Verifification

Test verify Confirmation
open | ../tests/html/test_confirm.html |
chooseCancelOnNextConfirmation |  |
click | confirmAndLeave |
verifyConfirmationPresent |  |
waitForConfirmationPresent |  |
assertConfirmationPresent |  |
verifyConfirmation | You are about to go to a dummy page. |
verifyTitle | Test Confirm |
clickAndWait | confirmAndLeave |
verifyConfirmation | *dummy page* |
verifyTitle | Dummy Page |
open | ../tests/html/test_confirm.html |
verifyTitle | Test Confirm |
chooseCancelOnNextConfirmation |  |
chooseOkOnNextConfirmation |  |
clickAndWait | confirmAndLeave |
verifyConfirmation | *dummy page* |
verifyTitle | Dummy Page |
open | ../tests/html/test_confirm.html |
assertFailureOnNext | There were no confirmations |
verifyConfirmation | This should fail - there are no confirmations |
clickAndWait | confirmAndLeave |
assertFailureOnNext | Actual value 'You are about to go to a dummy page.' did not match 'this should fail - wrong confirmation' |
verifyConfirmation | this should fail - wrong confirmation |
open | ../tests/html/test_confirm.html |
clickAndWait | confirmAndLeave |
assertErrorOnNext | There was an unexpected Confirmation! [You are about to go to a dummy page.] |
open | ../tests/html/test_confirm.html |